@@ -7,11 +7,11 @@ Created on Tue Apr 28 01:25:56 2020
 
 from . import fatty_alcohol_bioreactor
 from . import slle_centrifuge
-from biorefineries.cornstover.units import DAPTank, CSLTank 
+from biorefineries.cornstover.units import DAPStorageTank, CSLStorageTank 
 
 __all__ = (*fatty_alcohol_bioreactor.__all__,
            *slle_centrifuge.__all__,
-           'DAPTank', 'CSLTank',
+           'DAPStorageTank', 'CSLStorageTank',
 )
 
 from .fatty_alcohol_bioreactor import *
