@@ -7,7 +7,6 @@
 # for license details.
 """
 """
-from .. import PY37
 from . import (utils,
                _process_settings,
                _chemicals,
@@ -75,15 +74,12 @@ def _load_system(dct):
                                           T304, P303])
     _system_loaded = True
 
-if PY37:    
-    def __getattr__(name):
-        if not _chemicals_loaded:
-            _load_chemicals()
-            if name == 'chemicals': return chemicals
-        if not _system_loaded: 
-            dct = globals()
-            _load_system(dct)
-            if name in dct: return dct[name]
+def __getattr__(name):
+    if not _chemicals_loaded:
+        _load_chemicals()
+        if name == 'chemicals': return chemicals
+    if not _system_loaded: 
+        dct = globals()
+        _load_system(dct)
+        if name in dct: return dct[name]
         raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
-else:
-    load()
