@@ -11,12 +11,12 @@ from . import (
     units,
     _process_settings,
     _chemicals,
-    _system,
+    systems,
     _tea,
     _oil_extraction_specification,
     _distributions,
     _evaluation,
-    _box_plots,
+    _uncertainty_plots,
     _contour_plots,
     _lca_characterization_factors,
     _load_data,
@@ -26,12 +26,12 @@ from .units import *
 from ._process_settings import *
 from ._chemicals import *
 from ._contour_plots import *
-from ._system import *
+from .systems import *
 from ._tea import *
 from ._oil_extraction_specification import *
 from ._distributions import *
 from ._evaluation import *
-from ._box_plots import *
+from ._uncertainty_plots import *
 from ._contour_plots import *
 from ._lca_characterization_factors import *
 from ._load_data import *
@@ -42,12 +42,12 @@ __all__ = (
     units.__all__,
     *_process_settings.__all__,
     *_chemicals.__all__,
-    *_system.__all__,
+    *systems.__all__,
     *_tea.__all__,
     *_oil_extraction_specification.__all__,
     *_distributions.__all__,
     *_evaluation.__all__,
-    *_box_plots.__all__,
+    *_uncertainty_plots.__all__,
     *_contour_plots.__all__,
     *_lca_characterization_factors.__all__,
     *_load_data.__all__,
@@ -69,7 +69,7 @@ from chaospy import distributions as shape
 import numpy as np
 from ._process_settings import load_process_settings
 from ._chemicals import create_chemicals
-from ._system import (
+from .systems import (
     create_oilcane_to_biodiesel_and_ethanol_1g,
     create_oilcane_to_biodiesel_and_ethanol_combined_1_and_2g_post_fermentation_oil_separation,
     create_sugarcane_to_ethanol_combined_1_and_2g,    
@@ -112,10 +112,19 @@ _chemicals_loaded = False
 PRS = cs.PretreatmentReactorSystem
 PRS_cost_item = PRS.cost_items['Pretreatment reactor system']
 kg_per_ton = 907.18474
-
+kg_per_MT = 1000
+L_per_gal = 3.7854
+biodiesel_kg_per_gal = 3.3111
+biodiesel_gal_per_kg = 1. / biodiesel_kg_per_gal
+ethanol_kg_per_gal = 2.98668849
+ethanol_gal_per_kg = 1. / ethanol_kg_per_gal
+biodiesel_L_per_kg = biodiesel_gal_per_kg * L_per_gal
+biodiesel_kg_per_L = 1. / biodiesel_L_per_kg
+ethanol_L_per_kg = ethanol_gal_per_kg * L_per_gal
+ethanol_kg_per_L = 1. / ethanol_L_per_kg
 
 configuration_names = (
-    'S1', 'O1', 'S2', 'O2', 'S1*', 'O1*', 'S2*', 'O2*',
+    'S1', 'O1', 'S2', 'O2', 'S1*', 'O1*', 'S2*', 'O2*', 'O3', 'O4',
 )
 comparison_names = (
     # 'I - ∅', 
@@ -171,7 +180,7 @@ def load(name, cache={}, reduce_chemicals=True,
     dct = globals()
     number, agile = dct['configuration'] = configuration = parse(name)
     key = (number, agile, enhanced_cellulosic_performance)
-    if key in cache:
+    if cache is not None and key in cache:
         dct.update(cache[key])
         return
     global oilcane_sys, sys, tea, specs, flowsheet, _system_loaded
@@ -187,7 +196,7 @@ def load(name, cache={}, reduce_chemicals=True,
     load_process_settings()
     s = flowsheet.stream
     u = flowsheet.unit
-    operating_hours = 24 * 200
+    operating_hours = 24 * 180
     
     ## System
     
@@ -196,13 +205,13 @@ def load(name, cache={}, reduce_chemicals=True,
         bst.rename_units([i for i in oilcane_sys.units if bst.is_storage_unit(i)], storage)
     
     if number == -1:
-        isplit_efficiency_is_reversed = None
+        isplit_recovery_is_reversed = None
         # starting_chemicals = create_starting_chemicals()
         # bst.settings.set_thermo(starting_chemicals)
         oilcane_sys = create_sugarcane_to_ethanol_system(
             operating_hours=operating_hours,
             use_area_convention=True,
-            pellet_bagasse=True,
+            pellet_bagasse=False,
         )
         area_names = [
             'Feedstock handling', 
@@ -215,7 +224,7 @@ def load(name, cache={}, reduce_chemicals=True,
         ]
         rename_storage_units(700)
     elif number == -2:
-        isplit_efficiency_is_reversed = None
+        isplit_recovery_is_reversed = None
         oilcane_sys = create_sugarcane_to_ethanol_combined_1_and_2g(
             operating_hours=operating_hours,
         )
@@ -232,7 +241,7 @@ def load(name, cache={}, reduce_chemicals=True,
         ]
         rename_storage_units(900)
     elif number == 1:
-        isplit_efficiency_is_reversed = False
+        isplit_recovery_is_reversed = False
         oilcane_sys = create_oilcane_to_biodiesel_and_ethanol_1g(
             operating_hours=operating_hours,
         )
@@ -249,7 +258,7 @@ def load(name, cache={}, reduce_chemicals=True,
         ]
         rename_storage_units(1000)
     elif number == 2:
-        isplit_efficiency_is_reversed = True
+        isplit_recovery_is_reversed = True
         area_names = [
             'Feedstock handling', 
             'Juicing', 
@@ -267,8 +276,47 @@ def load(name, cache={}, reduce_chemicals=True,
             operating_hours=operating_hours,
         )
         rename_storage_units(1100)
+    elif number == 3:
+        isplit_recovery_is_reversed = False
+        oilcane_sys = create_oilcane_to_crude_oil_and_ethanol_1g(
+            operating_hours=operating_hours,
+        )
+        area_names = [
+            'Feedstock handling', 
+            'Juicing', 
+            'EtOH prod.', 
+            'Oil ext.', 
+            'CH&P',
+            'Utilities',
+            'HXN',
+            'Storage',
+        ]
+        rename_storage_units(800)
+    elif number == 4:
+        isplit_recovery_is_reversed = True
+        area_names = [
+            'Feedstock handling', 
+            'Juicing', 
+            'Pretreatment',
+            'EtOH prod.',
+            'Wastewater treatment',
+            'Oil ext.',
+            'CH&P', 
+            'Utilities',
+            'HXN',
+            'Storage',
+        ]
+        oilcane_sys = create_oilcane_to_crude_oil_and_ethanol_combined_1_and_2g_post_fermentation_oil_separation(
+            operating_hours=operating_hours,
+        )
+        rename_storage_units(1000)
     else:
         raise NotImplementedError(number)
+    if not number % 2:
+        for sys in oilcane_sys.subsystems:
+            for unit in sys.path:
+                if isinstance(unit, bst.AnaerobicDigestion):
+                    sys.converge_method = 'fixed-point'
     oilcane_sys.set_tolerance(rmol=1e-5, mol=1e-3, subsystems=True)
     dct.update(flowsheet.to_dict())
     
@@ -306,11 +354,11 @@ def load(name, cache={}, reduce_chemicals=True,
     unit_groups[-1].metrics[-1].getter = lambda: 0.    
     
     
-    if abs(number) == 2:
-        prs, = flowsheet(cs.units.PretreatmentReactorSystem)
-        saccharification, = flowsheet(cs.units.Saccharification)
-        seed_train, = flowsheet(cs.units.SeedTrain)
-        fermentor, = flowsheet(cs.units.CoFermentation)
+    if abs(number) in (2, 4):
+        prs = flowsheet(cs.units.PretreatmentReactorSystem)
+        saccharification = flowsheet(cs.units.Saccharification)
+        seed_train = flowsheet(cs.units.SeedTrain)
+        fermentor = flowsheet(cs.units.CoFermentation)
         dct['pretreatment_rxnsys'] = tmo.ReactionSystem(
             prs.reactions, saccharification.saccharification
         )
@@ -325,7 +373,7 @@ def load(name, cache={}, reduce_chemicals=True,
         prs.reactions.X[10] = 0.0 # baseline
             
     def set_glucose_yield(glucose_yield):
-        if abs(number) == 2:
+        if abs(number) in (2, 4):
             glucose_yield *= 0.01
             X1 = prs.reactions.X[0]
             X1_side = prs.reactions.X[1:3].sum()
@@ -335,7 +383,7 @@ def load(name, cache={}, reduce_chemicals=True,
             if X_excess > 0: breakpoint()
             
     def set_xylose_yield(xylose_yield):
-        if abs(number) == 2:
+        if abs(number) in (2, 4):
             xylose_yield *= 0.01
             X1_side = prs.reactions.X[9:11].sum()
             prs.reactions.X[8] = X1 = xylose_yield
@@ -366,7 +414,7 @@ def load(name, cache={}, reduce_chemicals=True,
         sys.operation_parameter(set_xylose_yield)
         
         dct['cane_mode'] = cane_mode = sys.operation_mode(oilcane_sys,
-            operating_hours=200*24, oil_content=0.05, feedstock=feedstock.copy(),
+            operating_hours=180*24, oil_content=0.05, feedstock=feedstock.copy(),
             z_mass_carbs_baseline=0.1491, glucose_yield=85, xylose_yield=65, 
             FFA_content=0.10, PL_content=0.10
         )
@@ -397,29 +445,32 @@ def load(name, cache={}, reduce_chemicals=True,
         isplit_b = None
         oil_extraction_specification = MockExtractionSpecification()
     else:
+        if number > 2:
+            dct['biodiesel'] = bst.Stream('biodiesel')
+        isplit_b = isplit_a = None
         for i in oilcane_sys.cost_units:
-            if getattr(i, 'tag', None) == 'oil extraction efficiency':
+            if getattr(i, 'tag', None) == 'oil extraction':
                 isplit_a = i.isplit
                 break
         
         for i in oilcane_sys.cost_units:
-            if getattr(i, 'tag', None) == 'bagasse oil retention':
+            if getattr(i, 'tag', None) == 'bagasse oil extraction':
                 isplit_b = i.isplit
                 break
         
         oil_extraction_specification = OilExtractionSpecification(
-            sys, [feedstock], isplit_a, isplit_b, isplit_efficiency_is_reversed
+            sys, [feedstock], isplit_a, isplit_b, isplit_recovery_is_reversed
         )
     
     ## LCA
     
     # Set non-negligible characterization factors
-    if abs(number) != 2:
+    if abs(number) not in (2, 4):
         for i in ('FGD_lime', 'cellulase', 'DAP', 'CSL', 'caustic'): MockStream(i)
-    if number < 0:
+    if number < 0 or number > 2:
         for i in ('catalyst', 'methanol', 'HCl', 'NaOH', 'crude_glycerol', 'pure_glycerine'): MockStream(i)
-    if abs(number) != 1:
-        MockStream('dryer_natural_gas')
+    # if abs(number) not in (1, 3):
+    #     MockStream('dryer_natural_gas')
         
     set_GWPCF(feedstock, 'sugarcane')
     set_GWPCF(s.H3PO4, 'H3PO4')
@@ -436,12 +487,12 @@ def load(name, cache={}, reduce_chemicals=True,
     set_GWPCF(s.HCl, 'HCl')
     set_GWPCF(s.NaOH, 'NaOH')
     set_GWPCF(s.pure_glycerine, 'pure-glycerol')
-    set_GWPCF(s.dryer_natural_gas, 'CH4')
+    # set_GWPCF(s.dryer_natural_gas, 'CH4')
     set_GWPCF(s.crude_glycerol, 'crude-glycerol', dilution=0.80)
     set_GWPCF(s.biodiesel, 'biodiesel displacement')
     bst.PowerUtility.set_CF(GWP, GWP_characterization_factors['Electricity'])
     dct['natural_gas_streams'] = natural_gas_streams = [s.natural_gas]
-    if abs(number) == 1: natural_gas_streams.append(s.dryer_natural_gas)
+    # if abs(number) in (1, 3): natural_gas_streams.append(s.dryer_natural_gas)
     for stream in natural_gas_streams:
         set_GWPCF(stream, 'CH4')
     
@@ -450,6 +501,14 @@ def load(name, cache={}, reduce_chemicals=True,
     parameter = model.parameter
     metric = model.metric
     
+    s.natural_gas.phase = 'g'
+    s.natural_gas.set_property('T', 60, 'degF')
+    s.natural_gas.set_property('P', 14.73, 'psi')
+    original_value = s.natural_gas.imol['CH4']
+    s.natural_gas.imass['CH4'] = 1 
+    V_ng = s.natural_gas.get_total_flow('m3/hr')
+    s.natural_gas.imol['CH4'] = original_value
+    
     def uniform(lb, ub, *args, **kwargs):
         return parameter(*args, distribution=shape.Uniform(lb, ub), bounds=(lb, ub), **kwargs)
     
@@ -468,46 +527,48 @@ def load(name, cache={}, reduce_chemicals=True,
     def triangular(lb, mid, ub, *args, **kwargs):
         return parameter(*args, distribution=shape.Triangle(lb, mid, ub), bounds=(lb, ub), **kwargs)
     
-    @uniform(40, 70, units='%', kind='coupled')
-    def set_bagasse_oil_retention(oil_retention):
-        oil_extraction_specification.load_oil_retention(oil_retention / 100.)
+    @uniform(60, 90, units='%', kind='coupled')
+    def set_crushing_mill_oil_recovery(oil_recovery):
+        oil_extraction_specification.load_crushing_mill_oil_recovery(oil_recovery / 100.)
     
-    def oil_extraction_efficiency_hook(x):
-        if number < 0:
-            return x
-        elif number == 1:
-            return 50.0 + x
-        elif number == 2:
-            return 70.0 + x
-    
-    @uniform(0., 20, units='%', kind='coupled', 
-             hook=oil_extraction_efficiency_hook)
-    def set_bagasse_oil_extraction_efficiency(bagasse_oil_extraction_efficiency):
-        oil_extraction_specification.load_efficiency(bagasse_oil_extraction_efficiency / 100.)
+    @uniform(70.0, 90, units='%', kind='coupled')
+    def set_saccharification_oil_recovery(saccharification_oil_recovery):
+        oil_extraction_specification.load_saccharification_oil_recovery(saccharification_oil_recovery / 100.)
 
-    capacity = feedstock.F_mass / kg_per_ton
-    @default(capacity, units='ton/hr', kind='coupled')
-    def set_plant_capacity(capacity):
-        feedstock.F_mass = F_mass = kg_per_ton * capacity
-        if agile: oilsorghum.F_mass = F_mass
+    # Baseline from Huang's 2016 paper, but distribution more in line with Florida sugarcane harvesting (3-5 months)
+    @uniform(4 * 30, 6 * 30, units='day/yr', baseline=180)
+    def set_cane_operating_days(cane_operating_days):
+        if agile:
+            cane_mode.operating_hours = cane_operating_days * 24
+        else:
+            tea.operating_days = cane_operating_days
+
+    # From Ed Cahoon and Huang 2017
+    @uniform(30, 60, units='day/yr', baseline=45)
+    def set_sorghum_operating_days(sorghum_operating_days):
+        if agile: sorghum_mode.operating_hours = sorghum_operating_days * 24
+    
+    @default(1600000, units='MT/yr', kind='coupled')
+    def set_annual_crushing_capacity(annual_crushing_capacity):
+        feedstock.F_mass = kg_per_MT * annual_crushing_capacity / tea.operating_hours
 
     # USDA ERS historical price data
     @parameter(distribution=ethanol_price_distribution, element=s.ethanol, 
-               baseline=1.90, units='USD/gal')
+               baseline=1.90 / L_per_gal, units='USD/L')
     def set_ethanol_price(price): # Triangular distribution fitted over the past 10 years Sep 2009 to Nov 2020
-        s.ethanol.price = price / 2.98668849
+        s.ethanol.price = price * ethanol_L_per_kg
         
     # USDA ERS historical price data
-    @parameter(distribution=biodiesel_minus_ethanol_price_distribution, element=s.biodiesel, units='USD/gal',
-               baseline=2.47, hook=lambda x: s.ethanol.price * 2.98668849 + x)
+    @parameter(distribution=biodiesel_minus_ethanol_price_distribution, element=s.biodiesel, units='USD/L',
+               baseline=2.47 / L_per_gal, hook=lambda x: s.ethanol.price + x)
     def set_biodiesel_price(price): # Triangular distribution fitted over the past 10 years Sep 2009 to March 2021
-        s.biodiesel.price = price / 3.3111
+        s.biodiesel.price = price * biodiesel_L_per_kg
 
     # https://www.eia.gov/energyexplained/natural-gas/prices.php
-    @parameter(distribution=natural_gas_price_distribution, element=s.natural_gas, units='USD/cf',
-               baseline=4.73)
+    @parameter(distribution=natural_gas_price_distribution, element=s.natural_gas, units='USD/m3',
+               baseline=4.73 / 35.3146667)
     def set_natural_gas_price(price): # Triangular distribution fitted over the past 10 years Sep 2009 to March 2021
-        BT.natural_gas_price = 51.92624700383502 * price / 1000. 
+        BT.natural_gas_price = price / V_ng
 
     # https://www.eia.gov/outlooks/aeo/pdf/00%20AEO2021%20Chart%20Library.pdf
     # Data from historical prices, 2010-2020
@@ -515,14 +576,6 @@ def load(name, cache={}, reduce_chemicals=True,
                 baseline=0.0637)
     def set_electricity_price(electricity_price): 
         bst.PowerUtility.price = electricity_price
-        
-    # From Huang's 2016 paper
-    @uniform(6 * 30, 7 * 30, units='day/yr', baseline=200)
-    def set_operating_days(operating_days):
-        if agile:
-            cane_mode.operating_hours = operating_days * 24
-        else:
-            tea.operating_days = operating_days
     
     # 10% is suggested for waste reducing, but 15% is suggested for investment
     @uniform(10., 15., units='%', baseline=10)
@@ -539,15 +592,15 @@ def load(name, cache={}, reduce_chemicals=True,
     
     @default(72, units='hr', element='Saccharification')
     def set_saccharification_reaction_time(reaction_time):
-        if abs(number) == 2: saccharification.tau = reaction_time
+        if abs(number) in (2, 4): saccharification.tau = reaction_time
     
     @default(0.212, units='USD/kg', element='cellulase')
     def set_cellulase_price(price):
-        if abs(number) == 2: s.cellulase.price = price
+        if abs(number) in (2, 4): s.cellulase.price = price
     
     @default(0.02, units='wt. % cellulose', element='cellulase')
     def set_cellulase_loading(cellulase_loading):
-        if abs(number) == 2: u.M302.cellulase_loading = cellulase_loading
+        if abs(number) in (2, 4): u.M302.cellulase_loading = cellulase_loading
     
     @default(PRS_cost_item.cost, units='million USD', element='Pretreatment reactor system')
     def set_reactor_base_cost(base_cost):
@@ -558,7 +611,7 @@ def load(name, cache={}, reduce_chemicals=True,
     def set_cane_glucose_yield(cane_glucose_yield):
         if agile:
             cane_mode.glucose_yield = cane_glucose_yield
-        elif abs(number) == 2:
+        elif abs(number) in (2, 4):
             set_glucose_yield(cane_glucose_yield)
     
     @uniform(79, 97.5, units='%', element='Pretreatment and saccharification',
@@ -572,7 +625,7 @@ def load(name, cache={}, reduce_chemicals=True,
     def set_cane_xylose_yield(cane_xylose_yield):
         if agile:
             cane_mode.xylose_yield = cane_xylose_yield
-        elif abs(number) == 2:
+        elif abs(number) in (2, 4):
             set_xylose_yield(cane_xylose_yield)
     
     @uniform(86, 97.5, units='%', element='Pretreatment and saccharification',
@@ -584,16 +637,16 @@ def load(name, cache={}, reduce_chemicals=True,
     @uniform(90, 95, units='%', element='Cofermenation',
              baseline=90)
     def set_glucose_to_ethanol_yield(glucose_to_ethanol_yield):
-        if abs(number) == 2:
+        if abs(number) in (2, 4):
             glucose_to_ethanol_yield *= 0.01
             # fermentor.cofermentation[2].X = 0.004 # Baseline
             # fermentor.cofermentation[3].X = 0.006 # Baseline
             # fermentor.loss[0].X = 0.03 # Baseline
-            split = np.mean(u.S403.split)
+            split = np.mean(u.S401.split)
             X1 = split * seed_train.reactions.X[0]
             X2 = split * seed_train.reactions.X[2]
             X3 = (glucose_to_ethanol_yield - X1) / (1 - X1 - X2)
-            split = np.mean(u.S403.split)
+            split = np.mean(u.S401.split)
             X_excess = X3 * 1.0526 - 1
             if X_excess > 0.: breakpoint()
             fermentor.cofermentation.X[0] = X3
@@ -602,13 +655,13 @@ def load(name, cache={}, reduce_chemicals=True,
     @uniform(50, 95, units='%', element='Cofermenation',
              baseline=50)
     def set_xylose_to_ethanol_yield(xylose_to_ethanol_yield):
-        if abs(number) == 2:
+        if abs(number) in (2, 4):
             # fermentor.cofermentation[6].X = 0.004 # Baseline
             # fermentor.cofermentation[7].X = 0.046 # Baseline
             # fermentor.cofermentation[8].X = 0.009 # Baseline
             # fermentor.loss[1].X = 0.03 # Baseline
             xylose_to_ethanol_yield *= 0.01
-            split = np.mean(u.S403.split)
+            split = np.mean(u.S401.split)
             X1 = split * seed_train.reactions.X[1]
             X2 = split * seed_train.reactions.X[3]
             X3 = (xylose_to_ethanol_yield - X1) / (1 - X1 - X2)
@@ -620,12 +673,12 @@ def load(name, cache={}, reduce_chemicals=True,
     @uniform(68.5, 137, units='g/L', element='Cofermentation',
              baseline=68.5)
     def set_cofermentation_titer(titer):
-        if abs(number) == 2: fermentor.titer = titer
+        if abs(number) in (2, 4): fermentor.titer = titer
 
     @uniform(0.951, 1.902, units='g/L', element='Cofermentation',
              baseline=0.951)
     def set_cofermentation_productivity(productivity):
-        if abs(number) == 2: fermentor.productivity = productivity
+        if abs(number) in (2, 4): fermentor.productivity = productivity
 
     @default(10, element='oilcane', units='% oil', kind='coupled')
     def set_cane_PL_content(cane_PL_content):
@@ -660,9 +713,9 @@ def load(name, cache={}, reduce_chemicals=True,
 
     @default(23, units='% oil', kind='coupled', name='TAG to FFA conversion')
     def set_TAG_to_FFA_conversion(TAG_to_FFA_conversion):
-        if number == 1:
+        if number in (1, 3):
             u.R301.oil_reaction.X[0] = TAG_to_FFA_conversion / 100.
-        elif number == 2:
+        elif number in (2, 4):
             u.R401.oil_reaction.X[0] = TAG_to_FFA_conversion / 100.
     
     @default_gwp(feedstock.characterization_factors[GWP], name='GWP', 
@@ -697,31 +750,23 @@ def load(name, cache={}, reduce_chemicals=True,
         for ng in natural_gas_streams:
             ng.characterization_factors[GWP] = value
     
-    s.natural_gas.phase = 'g'
-    s.natural_gas.set_property('T', 60, 'degF')
-    s.natural_gas.set_property('P', 14.73, 'psi')
-    original_value = s.natural_gas.imol['CH4']
-    s.natural_gas.imass['CH4'] = 1 
-    V_ng = s.natural_gas.get_total_flow('ft3/hr')
-    s.natural_gas.imol['CH4'] = original_value
-    
     if agile:
-        feedstock_flow = lambda: sys.flow_rates[feedstock] / kg_per_ton # ton/yr
-        biodiesel_flow = lambda: sys.flow_rates.get(s.biodiesel, 0.) / 3.3111 # gal/yr
-        ethanol_flow = lambda: sys.flow_rates[s.ethanol] / 2.98668849 # gal/yr
-        natural_gas_flow = lambda: sum([sys.flow_rates[i] for i in natural_gas_streams]) * V_ng # cf/yr
-        crude_glycerol_flow = lambda: sys.flow_rates.get(s.crude_glycerol, 0.) # kg/yr
+        feedstock_flow = lambda: sys.flow_rates[feedstock] / kg_per_MT # MT / yr
+        biodiesel_flow = lambda: sys.flow_rates.get(s.biodiesel, 0.) * biodiesel_L_per_kg # L / yr
+        ethanol_flow = lambda: sys.flow_rates[s.ethanol] * ethanol_L_per_kg # L / yr
+        natural_gas_flow = lambda: sum([sys.flow_rates[i] for i in natural_gas_streams]) * V_ng # m3 / yr
+        crude_glycerol_flow = lambda: sys.flow_rates.get(s.crude_glycerol, 0.) # kg / yr
         
         @sys.operation_metric(annualize=True)
         def direct_nonbiogenic_emissions(mode):
             return sum([i.F_mol for i in natural_gas_streams]) * chemicals.CO2.MW
         
     else:
-        feedstock_flow = lambda: sys.operating_hours * feedstock.F_mass / kg_per_ton # ton/yr
-        biodiesel_flow = lambda: sys.operating_hours * s.biodiesel.F_mass / 3.3111 # gal/yr
-        ethanol_flow = lambda: sys.operating_hours * s.ethanol.F_mass / 2.98668849 # gal/yr
-        crude_glycerol_flow = lambda: sys.operating_hours * s.crude_glycerol.F_mass # kg/yr
-        natural_gas_flow = lambda: sum([i.F_mass for i in natural_gas_streams]) * sys.operating_hours * V_ng # cf/yr
+        feedstock_flow = lambda: sys.operating_hours * feedstock.F_mass / kg_per_MT # MT / yr
+        biodiesel_flow = lambda: sys.operating_hours * s.biodiesel.F_mass * biodiesel_L_per_kg # L / yr
+        ethanol_flow = lambda: sys.operating_hours * s.ethanol.F_mass * ethanol_L_per_kg # L / yr
+        crude_glycerol_flow = lambda: sys.operating_hours * s.crude_glycerol.F_mass # kg / yr
+        natural_gas_flow = lambda: sum([i.F_mass for i in natural_gas_streams]) * sys.operating_hours * V_ng # m3 / yr
         direct_nonbiogenic_emissions = lambda: sum([i.F_mol for i in natural_gas_streams]) * chemicals.CO2.MW * sys.operating_hours
     electricity = lambda: sys.operating_hours * sys.power_utility.rate
     
@@ -741,30 +786,30 @@ def load(name, cache={}, reduce_chemicals=True,
         'crude_glycerol': crude_glycerol_flow,
         'electricity': electricity
     }
-    @metric(units='USD/ton')
+    @metric(units='USD/MT')
     def MFPP():
         price = tea.solve_price(feedstock)
-        return kg_per_ton * price
+        return kg_per_MT * price
     
-    @metric(units='ton/yr')
+    @metric(units='MT/yr')
     def feedstock_consumption():
         return feedstock_flow()
     
-    @metric(units='Gal/ton')
+    @metric(units='L/MT')
     def biodiesel_production():
         return biodiesel_flow() / feedstock_consumption.get()
     
-    @metric(units='Gal/ton')
+    @metric(units='L/MT')
     def ethanol_production():
         return ethanol_flow() / feedstock_consumption.get()
     
-    @metric(units='kWhr/ton')
+    @metric(units='kWhr/MT')
     def electricity_production():
         value = - electricity() / feedstock_consumption.get()
         if value < 0.: value = 0.
         return value
     
-    @metric(units='cf/ton')
+    @metric(units='m3/MT')
     def natural_gas_consumption():
         value = natural_gas_flow() / feedstock_consumption.get()
         return value
@@ -804,11 +849,11 @@ def load(name, cache={}, reduce_chemicals=True,
         )
         return (GWP_material + GWP_emissions) / sales
 
-    @metric(name='Ethanol GWP', element='Economic allocation', units='kg*CO2*eq / gal')
+    @metric(name='Ethanol GWP', element='Economic allocation', units='kg*CO2*eq / L')
     def GWP_ethanol(): # Cradle to gate
         return GWP_economic.get() * mean_ethanol_price
     
-    @metric(name='Biodiesel GWP', element='Economic allocation', units='kg*CO2*eq / gal')
+    @metric(name='Biodiesel GWP', element='Economic allocation', units='kg*CO2*eq / L')
     def GWP_biodiesel(): # Cradle to gate
         if number > 0:
             return GWP_economic.get() * mean_biodiesel_price
@@ -824,12 +869,12 @@ def load(name, cache={}, reduce_chemicals=True,
     
     @metric(name='Electricity GWP', element='Economic allocation', units='kg*CO2*eq / MWhr')
     def GWP_electricity(): # Cradle to gate
-        if abs(number) == 1:
+        if abs(number) in (1, 3):
             return GWP_economic.get() * mean_electricity_price * 1000.
         else:
             return 0.
 
-    @metric(name='Ethanol GWP', element='Displacement allocation', units='kg*CO2*eq / gal')
+    @metric(name='Ethanol GWP', element='Displacement allocation', units='kg*CO2*eq / L')
     def GWP_ethanol_displacement(): # Cradle to gate
         GWP_material = sys.get_total_feeds_impact(GWP)
         GWP_electricity_production = GWP_characterization_factors['Electricity'] * electricity_production.get() * feedstock_consumption.get()
@@ -848,17 +893,17 @@ def load(name, cache={}, reduce_chemicals=True,
         GWP_material = sys.get_total_feeds_impact(GWP)
         GWP_emissions = sys.get_process_impact(GWP) # kg CO2 eq. / yr
         GWP_total = GWP_material + GWP_emissions # kg CO2 eq. / yr
-        GGE_biodiesel_annual = (biodiesel_production.get() * feedstock_consumption.get()) / 0.9536
-        GGE_ethanol_annual = (ethanol_production.get() * feedstock_consumption.get()) / 1.5
+        GGE_biodiesel_annual = (biodiesel_production.get() * feedstock_consumption.get()) / 0.9536 / L_per_gal
+        GGE_ethanol_annual = (ethanol_production.get() * feedstock_consumption.get()) / 1.5 / L_per_gal
         GEE_electricity_production = max(-electricity() * 3600 / 114000, 0.) 
         GEE_crude_glycerol = crude_glycerol_flow() * 0.1059
         return GWP_total / (GGE_biodiesel_annual + GGE_ethanol_annual + GEE_electricity_production + GEE_crude_glycerol)
     
-    @metric(name='Ethanol GWP', element='Energy allocation', units='kg*CO2*eq / gal')
+    @metric(name='Ethanol GWP', element='Energy allocation', units='kg*CO2*eq / L')
     def GWP_ethanol_allocation(): # Cradle to gate
         return GWP_biofuel_allocation.get() / 1.5
     
-    @metric(name='Biodiesel GWP', element='Energy allocation', units='kg*CO2*eq / gal')
+    @metric(name='Biodiesel GWP', element='Energy allocation', units='kg*CO2*eq / L')
     def GWP_biodiesel_allocation(): # Cradle to gate
         if number > 0:
             return GWP_biofuel_allocation.get() / 0.9536
@@ -872,7 +917,7 @@ def load(name, cache={}, reduce_chemicals=True,
         else:
             return 0.
 
-    @metric(units='USD/ton')
+    @metric(units='USD/MT')
     def MFPP_derivative():
         if number < 0: return 0.
         if _derivative_disabled: return np.nan
@@ -882,35 +927,35 @@ def load(name, cache={}, reduce_chemicals=True,
         else:
             oil_extraction_specification.load_oil_content(oil_extraction_specification.oil_content + 0.01)
         sys.simulate()  
-        # value = (kg_per_ton * tea.solve_price(feedstock) - MFPP.cache)
+        # value = (kg_per_MT * tea.solve_price(feedstock) - MFPP.cache)
         # feedstock.price = tea.solve_price(feedstock)
         # print('AFTER')
-        # print('MFPP', kg_per_ton * tea.solve_price(feedstock))
+        # print('MFPP', kg_per_MT * tea.solve_price(feedstock))
         # print('VOC', tea.VOC / 1e3)
         # print('TCI', tea.TCI / 1e6)
         # print('sales', tea.sales / 1e3)
         # print('NPV', tea.NPV)
         return MFPP.difference()
     
-    @metric(units='Gal/ton')
+    @metric(units='L/MT')
     def biodiesel_production_derivative():
         if number < 0: return 0.
         if _derivative_disabled: return np.nan
         return biodiesel_production.difference()
     
-    @metric(units='Gal/ton')
+    @metric(units='L/MT')
     def ethanol_production_derivative():
         if number < 0: return 0.
         if _derivative_disabled: return np.nan
         return ethanol_production.difference()
     
-    @metric(units='kWhr/ton')
+    @metric(units='kWhr/MT')
     def electricity_production_derivative():
         if number < 0: return 0.
         if _derivative_disabled: return np.nan
         return electricity_production.difference()
     
-    @metric(units='cf/ton')
+    @metric(units='cf/MT')
     def natural_gas_consumption_derivative():
         if number < 0: return 0.
         if _derivative_disabled: return np.nan
@@ -929,11 +974,11 @@ def load(name, cache={}, reduce_chemicals=True,
         if _derivative_disabled: return np.nan
         return GWP_economic.difference()
 
-    @metric(name='Ethanol GWP derivative', element='Ethanol', units='kg*CO2*eq / gal')
+    @metric(name='Ethanol GWP derivative', element='Ethanol', units='kg*CO2*eq / L')
     def GWP_ethanol_derivative(): # Cradle to gate
         return GWP_economic_derivative.get() * mean_ethanol_price
     
-    @metric(name='Biodiesel GWP derivative', element='Biodiesel', units='kg*CO2*eq / gal')
+    @metric(name='Biodiesel GWP derivative', element='Biodiesel', units='kg*CO2*eq / L')
     def GWP_biodiesel_derivative(): # Cradle to gate
         if number > 0:
             return GWP_economic_derivative.get() * mean_biodiesel_price
@@ -949,7 +994,7 @@ def load(name, cache={}, reduce_chemicals=True,
     
     @metric(name='Electricity GWP derivative', element='Electricity', units='kg*CO2*eq / MWhr')
     def GWP_electricity_derivative(): # Cradle to gate
-        if abs(number) == 1:
+        if abs(number) in (1, 3):
             return GWP_economic_derivative.get() * mean_electricity_price * 1000.
         else:
             return 0.
@@ -962,13 +1007,12 @@ def load(name, cache={}, reduce_chemicals=True,
     #         - natural_gas_flow() / 126.67)
     #     return GGE / 1e6
     
-    
     # Single point evaluation for detailed design results
     def set_baseline(p, x):
         p.setter(x)
         p.baseline = x
     
-    if abs(number) == 2:
+    if abs(number) in (2, 4):
         if enhanced_cellulosic_performance:
             set_baseline(set_sorghum_glucose_yield, 97.5)
             set_baseline(set_sorghum_xylose_yield, 97.5)
@@ -985,14 +1029,13 @@ def load(name, cache={}, reduce_chemicals=True,
             set_baseline(set_cane_xylose_yield, 97.5)
             set_baseline(set_glucose_to_ethanol_yield, 90)
             set_baseline(set_xylose_to_ethanol_yield, 42)
-    if number == 1 and enhanced_biodiesel_production:
+    if number in (1, 3) and enhanced_biodiesel_production:
         set_baseline(set_cane_oil_content, 15)
-        set_baseline(set_bagasse_oil_extraction_efficiency, oil_extraction_efficiency_hook(20))
-        set_baseline(set_bagasse_oil_retention, 40)
+        set_baseline(set_saccharification_oil_recovery, 95)
     else:
         set_baseline(set_cane_oil_content, 5)
-        set_baseline(set_bagasse_oil_extraction_efficiency, oil_extraction_efficiency_hook(0.))
-        set_baseline(set_bagasse_oil_retention, 70)
+        set_baseline(set_saccharification_oil_recovery, 70)
+    set_baseline(set_crushing_mill_oil_recovery, 60)
     set_baseline(set_ethanol_price, mean_ethanol_price) 
     set_baseline(set_crude_glycerol_price, mean_glycerol_price)
     set_baseline(set_biodiesel_price, mean_biodiesel_price)
@@ -1009,13 +1052,19 @@ def load(name, cache={}, reduce_chemicals=True,
     # set_electricity_price(0.0572) # Consistent with Humbird's 2012 paper
     # set_operating_days(200) # Consistent with Huang's 2016 paper
     
+    for i in sys.units:
+        if isinstance(i, bst.MultiEffectEvaporator): i.flash = False
+    
     for i in model._parameters:
         dct[i.setter.__name__] = i
     for i in model._metrics:
         dct[i.getter.__name__] = i
-    cache[key] = dct.copy()
+    if cache is not None: cache[key] = dct.copy()
     
     ## Simulation
+    HXN.force_ideal_thermo = True
+    HXN.cache_network = True
+    HXN.avoid_recycle = True
     try: 
         sys.simulate()
     except Exception as e:
@@ -1023,8 +1072,6 @@ def load(name, cache={}, reduce_chemicals=True,
     if reduce_chemicals:
         oilcane_sys.reduce_chemicals()
     oilcane_sys._load_stream_links()
-    HXN.force_ideal_thermo = True
-    HXN.cache_network = True
     HXN.simulate()
 
 # DO NOT DELETE: For removing ylabel and yticklabels and combine plots
